==> huaweicloudsdkworkspaceapp-3.1.134-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/send_authorized_mail_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SendAuthorizedMailRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'body': 'ResendAuthorizedMailReq'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'body': 'body'
    }

    def __init__(self, x_language=None, body=None):
        """SendAuthorizedMailRequest

        The model defined in huaweicloud sdk

        :param x_language: 语言： - zh-cn：中文 - en-us：英文 - fr-fr: 法文
        :type x_language: str
        :param body: Body of the SendAuthorizedMailRequest
        :type body: :class:`huaweicloudsdkworkspaceapp.v1.ResendAuthorizedMailReq`
        """
        
        

        self._x_language = None
        self._body = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        if body is not None:
            self.body = body

    @property
    def x_language(self):
        """Gets the x_language of this SendAuthorizedMailRequest.

        语言： - zh-cn：中文 - en-us：英文 - fr-fr: 法文

        :return: The x_language of this SendAuthorizedMailRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this SendAuthorizedMailRequest.

        语言： - zh-cn：中文 - en-us：英文 - fr-fr: 法文

        :param x_language: The x_language of this SendAuthorizedMailRequest.
        :type x_language: str
        """
        self._x_language = x_language

    @property
    def body(self):
        """Gets the body of this SendAuthorizedMailRequest.

        :return: The body of this SendAuthorizedMailRequest.
        :rtype: :class:`huaweicloudsdkworkspaceapp.v1.ResendAuthorizedMailReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this SendAuthorizedMailRequest.

        :param body: The body of this SendAuthorizedMailRequest.
        :type body: :class:`huaweicloudsdkworkspaceapp.v1.ResendAuthorizedMailReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendAuthorizedMailRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspaceapp-3.1.156-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/send_authorized_mail_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SendAuthorizedMailRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'body': 'ResendAuthorizedMailReq'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'body': 'body'
    }

    def __init__(self, x_language=None, body=None):
        r"""SendAuthorizedMailRequest

        The model defined in huaweicloud sdk

        :param x_language: 语言： - zh-cn：中文 - en-us：英文 - fr-fr: 法文
        :type x_language: str
        :param body: Body of the SendAuthorizedMailRequest
        :type body: :class:`huaweicloudsdkworkspaceapp.v1.ResendAuthorizedMailReq`
        """
        
        

        self._x_language = None
        self._body = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        if body is not None:
            self.body = body

    @property
    def x_language(self):
        r"""Gets the x_language of this SendAuthorizedMailRequest.

        语言： - zh-cn：中文 - en-us：英文 - fr-fr: 法文

        :return: The x_language of this SendAuthorizedMailRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        r"""Sets the x_language of this SendAuthorizedMailRequest.

        语言： - zh-cn：中文 - en-us：英文 - fr-fr: 法文

        :param x_language: The x_language of this SendAuthorizedMailRequest.
        :type x_language: str
        """
        self._x_language = x_language

    @property
    def body(self):
        r"""Gets the body of this SendAuthorizedMailRequest.

        :return: The body of this SendAuthorizedMailRequest.
        :rtype: :class:`huaweicloudsdkworkspaceapp.v1.ResendAuthorizedMailReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this SendAuthorizedMailRequest.

        :param body: The body of this SendAuthorizedMailRequest.
        :type body: :class:`huaweicloudsdkworkspaceapp.v1.ResendAuthorizedMailReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendAuthorizedMailRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
